@@ -5,10 +5,9 @@ import os
 import sys
 import time
 import re
-
+import html
 from nonebot.log import logger_id
 from nonebot.log import  default_filter
-
 from nonebot import logger
 import webuiapi
 from revChatGPT.V1 import Chatbot as chatGPT
@@ -45,13 +44,13 @@ logger.level('suc',no=25)
 logger.level('err',no=40)
 logger.level('FBOT',no=20)
 
-def info(app:str,text:str): logger.opt(colors=True).log('FBOT',f"[{app}] {text}")
-def error(app:str,text:str): logger.opt(colors=True).error(f"[{app}] {text}")
-def success(app:str,text:str): logger.opt(colors=True).success(f"[{app}] {text}")
-def warn(app:str,text:str): logger.opt(colors=True).warning(f"[{app}] {text}")
-def debug(app:str,text:str): logger.opt(colors=True).debug(f"[{app}] {text}")
-def suc(app:str,text:str): logger.opt(colors=True).log('suc',f"[{app}] {text}")
-def err(app:str,text:str): logger.opt(colors=True).log('err',f"[{app}] {text}")
+def info(app:str,text:str): logger.opt(colors=True).log('FBOT',f"[{app}] {html.escape(text)}")
+def error(app:str,text:str): logger.opt(colors=True).error(f"[{app}] {html.escape(text)}")
+def success(app:str,text:str): logger.opt(colors=True).success(f"[{app}] {html.escape(text)}")
+def warn(app:str,text:str): logger.opt(colors=True).warning(f"[{app}] {html.escape(text)}")
+def debug(app:str,text:str): logger.opt(colors=True).debug(f"[{app}] {html.escape(text)}")
+def suc(app:str,text:str): logger.opt(colors=True).log('suc',f"[{app}] {html.escape(text)}")
+def err(app:str,text:str): logger.opt(colors=True).log('err',f"[{app}] {html.escape(text)}")
 
 from dotenv import dotenv_values, load_dotenv, set_key
 cfg = {
@@ -72,7 +71,7 @@ cfg = {
 
 async def Chat(func,message:str,mode=1): 
     if not message or len(message)<1:return
-    Rtime = cfg['Chat_stream_waitTime']
+    Rtime = int(cfg['Chat_stream_waitTime'])
     endStr = cfg['Chat_stream_endStr']
     text = ''
     out_text=''
@@ -117,7 +116,7 @@ async def Chat_api(func,message:str,mode=1):
 
 async def Bing(func,message,mode=1):
     if not message or len(message)<1:return
-    Rtime = cfg['Chat_stream_waitTime']
+    Rtime = int(cfg['Chat_stream_waitTime'])
     endStr = cfg['Chat_stream_endStr']
     text = ''
     out_text=''
@@ -145,6 +144,7 @@ async def text2image(func,prompt):
     ip = cfg['text2img_proxy'].split(':')
     info('Stable-Diffusion','开始询问 api'+cfg['text2img_proxy'])
     api = webuiapi.WebUIApi(host=ip[0], port=ip[1]) # type: ignore
+    
     result1 = api.txt2img(
         prompt=prompt,
         negative_prompt=cfg['text2img_negative_prompt'],
@@ -165,25 +165,29 @@ async def startup():
     if not os.path.exists('./config.cfg'):
         with open('config.cfg', 'w',encoding='utf-8') as f:
             text = """
-text2img_step=27
-text2img_negative_prompt="(worst quality, low quality:1.4),NSFW,r18"
-text2img_proxy='127.0.0.1:7860'
+# "#"后面的为注释
 
-presets_dir='./presets'
-Chat_stream_waitTime=2
-Chat_stream_endStr=('？','。','?','\\n')
-defaultAI='chatGPT'
+Stable-Diffusion # Stable-Diffusion 配置:
+text2img_step=27 # 文生图 渲染步数
+text2img_negative_prompt="(worst quality, low quality:1.4),NSFW,r18" #文生图 固定负面提示词
+text2img_proxy='127.0.0.1:7860' #Stable-Diffusion api地址 (SD内配置 --server-name 127.0.0.1 --port 7860 --api)
 
-chatGPT # ChatGPT 配置:
-access_token=""
+chat # 聊天 api 通用设置:
+presets_dir='./presets' # 预设文件夹
+Chat_stream_waitTime=2 # 频道内 分条发送间隔 (秒)
+Chat_stream_endStr=('？','。','?','\n') # 频道内 分条发送分割依据
+defaultAI='chatGPT' # 默认 AI
+
+chatGPT # ChatGPT 配置 (网页):
+access_token="" # access_token  获取:https://chat.openai.com/api/auth/session
 
 chatGPT_api # ChatGPT api 配置:
-api_key=""
+api_key="" # api_key 获取:https://platform.openai.com/account/api-keys
 model="gpt-3.5-turbo"
 
 bing # Bing api 配置:
-cookies_file_path="./cookies.json"
-            """
+cookies_file_path="./cookies.json" # 设置:https://github.com/thx114/SDGPT/wiki/bing-cookies
+"""
             f.write(text)
 
 
